Learn R Programming

bayesQRsurvey (version 0.1.4)

Anthro: Children anthropometric data

Description

The dataset consists of 1007 observations and 6 variables of children aged between 0 and 60 months from the Central-West of Brazil. The data is a subset of the 2006 Brazilian National Demographic Health Survey of Women and Children (NDHS), which is a complex survey where the sampling units were selected in two stages: primary sampling units (PSUs) comprised census tracts, and secondary sampling units (SSUs) consisted of households. Tract selection in each stratum was designed to ensure a minimum number of blood samples, based on the prevalence of vitamin A deficiency in children.

Usage

data("Anthro")

Arguments

Format

The data frame has the following components:

  • wgt : weight

  • hgt : height

  • ruc : rural-urban classification (urban = 1 and rural = 2)

  • sex : boy = 1 and girl = 2

  • age : age in months

  • dweight : sampling weights