Learn R Programming

bayesQRsurvey (version 0.1.4)

bayesQRsurvey-package: bayesQRsurvey: Bayesian Weighted Quantile Regression for complex survey designs with EM and MCMC Algorithm

Description

The bayesQRsurvey package provides Bayesian quantile regression methods for complex survey designs with two main functions:

Arguments

Main functions

bqr.svy

Fits Bayesian quantile regression for multiple quantiles using MCMC methods (ALD, Score, Approximate)

mo.bqr.svy

Fits Bayesian quantile regression for multiple quantiles using EM algorithm

plot

Standard plot method for bqr.svy objects

summary

Unified summary method for all bayesQRsurvey model objects

prior

Unified interface for creating prior distributions

MCMC Methods

The bqr.svy function can estimate three types of models, where the quantile regression coefficients are defined at the super-population level, and their estimators are built upon the survey weights.:

  • ALD (Asymmetric Laplace Distribution): Uses asymmetric Laplace likelihood

  • Score: Uses score-based approach

  • Approximate: Uses approximate methods for faster computation

EM Algorithm

Implements a Bayesian approach to multiple-output quantile regression for complex survey data analysis.

Author

Marcus L. Nascimento, Kelly Cristina Mota Goncalves, Johnatan Cardona Jimenez, Tomas Rodriguez Taborda

Details

  • bqr.svy(): Bayesian methods for estimating quantile regression models using MCMC methods

  • mo.bqr.svy(): Bayesian approach to multiple-output quantile regression using EM algorithm

References

Yu, K. and Moyeed, R. A. (2001). Bayesian quantile regression. Statistics & Probability Letters, 54(4), 437-447.

Kozumi, H. and Kobayashi, G. (2011). Gibbs sampling methods for Bayesian quantile regression. Journal of Statistical Computation and Simulation, 81(11), 1565-1578.

See Also