The bayesQRsurvey package provides Bayesian quantile regression methods for complex survey designs with two main functions:
bqr.svyFits Bayesian quantile regression for multiple quantiles using MCMC methods (ALD, Score, Approximate)
mo.bqr.svyFits Bayesian quantile regression for multiple quantiles using EM algorithm
plotStandard plot method for bqr.svy objects
summaryUnified summary method for all bayesQRsurvey model objects
priorUnified interface for creating prior distributions
The bqr.svy function can estimate three types of models, where the quantile regression coefficients are defined at the super-population level, and their estimators are built upon the survey weights.:
ALD (Asymmetric Laplace Distribution): Uses asymmetric Laplace likelihood
Score: Uses score-based approach
Approximate: Uses approximate methods for faster computation
Implements a Bayesian approach to multiple-output quantile regression for complex survey data analysis.
Marcus L. Nascimento, Kelly Cristina Mota Goncalves, Johnatan Cardona Jimenez, Tomas Rodriguez Taborda
bqr.svy(): Bayesian methods for estimating quantile regression models
using MCMC methods
mo.bqr.svy(): Bayesian approach to multiple-output quantile regression
using EM algorithm
Yu, K. and Moyeed, R. A. (2001). Bayesian quantile regression. Statistics & Probability Letters, 54(4), 437-447.
Kozumi, H. and Kobayashi, G. (2011). Gibbs sampling methods for Bayesian quantile regression. Journal of Statistical Computation and Simulation, 81(11), 1565-1578.
Useful links: